<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\interfaces;

interface CanMasqueradeInterface
{
    public function canMasqueradeAs(CanBeMasqueradedInterface $to): bool;

    public function getId(): int;
}