<?php
declare(strict_types=1);

use Phinx\Migration\AbstractMigration;

final class RemoveSaltFromUser extends AbstractMigration
{
    public function change(): void
    {
        $this->table('users')
            ->removeColumn('salt')
            ->update();
    }
}
